@@ -1,6 +1,8 @@
 import dataclasses
 import typing
+import warnings
 
+from .internal import __version__ as __version__
 from .internal.dynamic import Branch as Branch
 from .internal.dynamic import Leaf as Leaf
 from .internal.dynamic import Node as Node
@@ -67,79 +69,137 @@ from .internal.parsec import AnyTalonRule as AnyTalonRule
 from .internal.parsec import find_command as find_command
 from .internal.parsec import match as match
 
-################################################################################
-# Version Number
-################################################################################
-
-# TODO: Switch to "1!{tree-sitter-talon.version}.{build}".
-#       Blocked on <python-poetry/poetry/issues/6466>.
-
-__version__: str = "1003.3.1.0"
-#                   ^^^^ build
-#                        ^^^^^ tree-sitter-talon version
-
-
 ################################################################################
 # Properties for backwards compatibility
 ################################################################################
 
 
 def _TalonMatch_key(self) -> TalonIdentifier:
+    warnings.warn(
+        "'key' was deprecated in 1004.3.1.0; use 'left'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return self.left
 
 
-setattr(TalonMatch, "key", property(_TalonMatch_key))
+setattr(
+    TalonMatch,
+    "key",
+    property(_TalonMatch_key),
+)
 
 
 def _TalonMatch_modifier(self) -> TalonIdentifier:
+    warnings.warn(
+        "'modifier' was deprecated in 1004.3.1.0; use 'modifiers'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return self.modifiers
 
 
-setattr(TalonMatch, "modifier", property(_TalonMatch_modifier))
+setattr(
+    TalonMatch,
+    "modifier",
+    property(_TalonMatch_modifier),
+)
 
 
 def _TalonMatch_pattern(self) -> TalonIdentifier:
-    return self.right
-
-
-setattr(TalonMatch, "pattern", property(_TalonMatch_pattern))
-
-
-def _TalonCommandDeclaration_rule(self) -> TalonIdentifier:
-    return self.left
-
-
-setattr(TalonCommandDeclaration, "rule", property(_TalonCommandDeclaration_rule))
-
-
-def _TalonCommandDeclaration_script(self) -> TalonIdentifier:
-    return self.right
-
-
-setattr(TalonCommandDeclaration, "script", property(_TalonCommandDeclaration_script))
-
-
-def _TalonKeyBindingDeclaration_key(self) -> TalonIdentifier:
-    return self.left
-
-
-setattr(TalonKeyBindingDeclaration, "key", property(_TalonKeyBindingDeclaration_key))
-
-
-def _TalonKeyBindingDeclaration_script(self) -> TalonIdentifier:
+    warnings.warn(
+        "'pattern' was deprecated in 1004.3.1.0; use 'right'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return self.right
 
 
 setattr(
-    TalonKeyBindingDeclaration, "script", property(_TalonKeyBindingDeclaration_script)
+    TalonMatch,
+    "pattern",
+    property(_TalonMatch_pattern),
+)
+
+
+def _TalonCommandDeclaration_rule(self) -> TalonIdentifier:
+    warnings.warn(
+        "'rule' was deprecated in 1004.3.1.0; use 'left'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    return self.left
+
+
+setattr(
+    TalonCommandDeclaration,
+    "rule",
+    property(_TalonCommandDeclaration_rule),
+)
+
+
+def _TalonCommandDeclaration_script(self) -> TalonIdentifier:
+    warnings.warn(
+        "'script' was deprecated in 1004.3.1.0; use 'right'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    return self.right
+
+
+setattr(
+    TalonCommandDeclaration,
+    "script",
+    property(_TalonCommandDeclaration_script),
+)
+
+
+def _TalonKeyBindingDeclaration_key(self) -> TalonIdentifier:
+    warnings.warn(
+        "'key' was deprecated in 1004.3.1.0; use 'left'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    return self.left
+
+
+setattr(
+    TalonKeyBindingDeclaration,
+    "key",
+    property(_TalonKeyBindingDeclaration_key),
+)
+
+
+def _TalonKeyBindingDeclaration_script(self) -> TalonIdentifier:
+    warnings.warn(
+        "'script' was deprecated in 1004.3.1.0; use 'right'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    return self.right
+
+
+setattr(
+    TalonKeyBindingDeclaration,
+    "script",
+    property(_TalonKeyBindingDeclaration_script),
 )
 
 
 def _TalonTagImportDeclaration_tag(self) -> TalonIdentifier:
+    warnings.warn(
+        "'tag' was deprecated in 1004.3.1.0; use 'right'",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return self.right
 
 
-setattr(TalonTagImportDeclaration, "tag", property(_TalonTagImportDeclaration_tag))
+setattr(
+    TalonTagImportDeclaration,
+    "tag",
+    property(_TalonTagImportDeclaration_tag),
+)
 
 
 ################################################################################
